==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/filedesc/translations/filedesc_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Plik z opisem do synchronizacji</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Wpisz tutaj nazwę pliku, który będzie zawierał opisy do odświeżania przez moduł.</translation>
    </message>
    <message>
        <source>Force status to be &apos;with description&apos;</source>
        <translation>Zmuszaj status, aby był &apos;z opisem&apos;</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Jeśli wybierzesz status bez opisu, moduł automatycznie ustawi analogiczny, ale z opisem</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Dopuść inne opisy</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Umożliwia ustawienie własnego opisu dopóki zawartość pliku nie ulegnie zmianie</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/filedesc/translations/filedesc_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Plik z opisem do synchronizacji</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Wpisz tutaj nazwę pliku, który będzie zawierał opisy do odświeżania przez moduł.</translation>
    </message>
    <message>
        <source>Force status to be &apos;with description&apos;</source>
        <translation>Zmuszaj status, aby był &apos;z opisem&apos;</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Jeśli wybierzesz status bez opisu, moduł automatycznie ustawi analogiczny, ale z opisem</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Dopuść inne opisy</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Umożliwia ustawienie własnego opisu dopóki zawartość pliku nie ulegnie zmianie</translation>
    </message>
</context>
</TS>
